
from imagescanner.core._imagescanner import ImageScanner

# Configure the python logging using the custom handler
from imagescanner.utils.logger import config_logger as _config_logger
_config_logger()
